==> plplot-5.12.0.tar.gz: plplot-5.12.0/doc/doxygen/html/search/functions_d.js <==
var searchData=
[
  ['n2q',['n2q',['../csa_8c.html#a1e25648a3bbcc22eefc791dae8584da3',1,'csa.c']]],
  ['nextpage',['NextPage',['../plplotter_8c.html#ada6ffbd50407eb5fa8c54408aa5ff65b',1,'NextPage(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a4ac458c0f599e34821e980876104366c',1,'NextPage(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **PL_UNUSED(argv)):&#160;plplotter.c']]],
  ['nn_5fquit',['nn_quit',['../nnai_8c.html#aa74fb4b5bc70560fa58e6d2e32124e4b',1,'nn_quit(const char *format,...):&#160;nncommon.c'],['../nncommon_8c.html#aa74fb4b5bc70560fa58e6d2e32124e4b',1,'nn_quit(const char *format,...):&#160;nncommon.c'],['../nnpi_8c.html#aa74fb4b5bc70560fa58e6d2e32124e4b',1,'nn_quit(const char *format,...):&#160;nncommon.c']]],
  ['nnai_5fbuild',['nnai_build',['../nn_8h.html#a100f5dd2bea6f1cdc38cd5aeaded290f',1,'nnai_build(delaunay *d, int n, double *x, double *y):&#160;nnai.c'],['../nnai_8c.html#a100f5dd2bea6f1cdc38cd5aeaded290f',1,'nnai_build(delaunay *d, int n, double *x, double *y):&#160;nnai.c']]],
  ['nnai_5fdestroy',['nnai_destroy',['../nn_8h.html#a8f632f77d6ebbdd5f089b2ac1a8fb19c',1,'nnai_destroy(nnai *nn):&#160;nnai.c'],['../nnai_8c.html#a8f632f77d6ebbdd5f089b2ac1a8fb19c',1,'nnai_destroy(nnai *nn):&#160;nnai.c']]],
  ['nnai_5finterpolate',['nnai_interpolate',['../nn_8h.html#ac3e0c1fbe589c8ab85f9206c28e5eea6',1,'nnai_interpolate(nnai *nn, double *zin, double *zout):&#160;nnai.c'],['../nnai_8c.html#ac3e0c1fbe589c8ab85f9206c28e5eea6',1,'nnai_interpolate(nnai *nn, double *zin, double *zout):&#160;nnai.c']]],
  ['nnai_5fsetwmin',['nnai_setwmin',['../nn_8h.html#aca836e74dc7b0a1d0175263ce86db6f7',1,'nnai_setwmin(nnai *nn, double wmin):&#160;nnai.c'],['../nnai_8c.html#aca836e74dc7b0a1d0175263ce86db6f7',1,'nnai_setwmin(nnai *nn, double wmin):&#160;nnai.c']]],
  ['nndllimpexp_5fdata',['NNDLLIMPEXP_DATA',['../nn_8h.html#ae0d9952ca6772ec1a2c322b79de7e409',1,'nn.h']]],
  ['nnhpi_5fcreate',['nnhpi_create',['../nn_8h.html#a63afdbb12466d8f0fa6a92cc560626cb',1,'nnhpi_create(delaunay *d, int size):&#160;nnpi.c'],['../nnpi_8c.html#a63afdbb12466d8f0fa6a92cc560626cb',1,'nnhpi_create(delaunay *d, int size):&#160;nnpi.c']]],
  ['nnhpi_5fdestroy',['nnhpi_destroy',['../nn_8h.html#af805b7c134095adcfe445d04a1780751',1,'nnhpi_destroy(nnhpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#af805b7c134095adcfe445d04a1780751',1,'nnhpi_destroy(nnhpi *nn):&#160;nnpi.c']]],
  ['nnhpi_5finterpolate',['nnhpi_interpolate',['../nn_8h.html#a6e1fbbdaba1c48008e16b3d65c1ec423',1,'nnhpi_interpolate(nnhpi *nn, point *p):&#160;nnpi.c'],['../nnpi_8c.html#a5b97d1ae6654d20963afbdd700bc9475',1,'nnhpi_interpolate(nnhpi *nnhp, point *p):&#160;nnpi.c']]],
  ['nnhpi_5fmodify_5fdata',['nnhpi_modify_data',['../nn_8h.html#a3decc00fe86197535faf340c071c4187',1,'nnhpi_modify_data(nnhpi *nn, point *p):&#160;nnpi.c'],['../nnpi_8c.html#a5fe3c0f0f14ba9724316b49c055e17c5',1,'nnhpi_modify_data(nnhpi *nnhp, point *p):&#160;nnpi.c']]],
  ['nnhpi_5fsetwmin',['nnhpi_setwmin',['../nn_8h.html#ada49b80c66b0b454cf9c767aac6e9622',1,'nnhpi_setwmin(nnhpi *nn, double wmin):&#160;nnpi.c'],['../nnpi_8c.html#ada49b80c66b0b454cf9c767aac6e9622',1,'nnhpi_setwmin(nnhpi *nn, double wmin):&#160;nnpi.c']]],
  ['nnpi_5fadd_5fweight',['nnpi_add_weight',['../nnpi_8c.html#a156da6be13470e2871b79f0e9e51e357',1,'nnpi.c']]],
  ['nnpi_5fcalculate_5fweights',['nnpi_calculate_weights',['../nnai_8c.html#ae678a0d48730f7e83c8a2c014ed6ee9f',1,'nnpi_calculate_weights(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#ae678a0d48730f7e83c8a2c014ed6ee9f',1,'nnpi_calculate_weights(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fcreate',['nnpi_create',['../nn_8h.html#aedcc30006ab88310a79e0e209631c498',1,'nnpi_create(delaunay *d):&#160;nnpi.c'],['../nnpi_8c.html#aedcc30006ab88310a79e0e209631c498',1,'nnpi_create(delaunay *d):&#160;nnpi.c']]],
  ['nnpi_5fdestroy',['nnpi_destroy',['../nn_8h.html#a33db53e6adc0c3997fd8bb40b643c055',1,'nnpi_destroy(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#a33db53e6adc0c3997fd8bb40b643c055',1,'nnpi_destroy(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fget_5fnvertices',['nnpi_get_nvertices',['../nnai_8c.html#a98f78819ec51952b6d345cd412734c2a',1,'nnpi_get_nvertices(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#a98f78819ec51952b6d345cd412734c2a',1,'nnpi_get_nvertices(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fget_5fvertices',['nnpi_get_vertices',['../nnai_8c.html#a4c6b67ae981d5c38a44a2b2f1f187691',1,'nnpi_get_vertices(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#a2f63ce3a965902fd447069e2020f55dd',1,'nnpi_get_vertices(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fget_5fweights',['nnpi_get_weights',['../nnai_8c.html#acf3056c75581a8a40b63eefac3de04c9',1,'nnpi_get_weights(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#ae9f69c53b06d4ee1a5bc29441af16b4d',1,'nnpi_get_weights(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5finterpolate_5fpoint',['nnpi_interpolate_point',['../nn_8h.html#a5975e4d072aa2275b5a0231770d97251',1,'nnpi_interpolate_point(nnpi *nn, point *p):&#160;nnpi.c'],['../nnpi_8c.html#a5975e4d072aa2275b5a0231770d97251',1,'nnpi_interpolate_point(nnpi *nn, point *p):&#160;nnpi.c']]],
  ['nnpi_5finterpolate_5fpoints',['nnpi_interpolate_points',['../nn_8h.html#ade086ca1784d7687d20ed7e48cd666f5',1,'nnpi_interpolate_points(int nin, point pin[], double wmin, int nout, point pout[]):&#160;nnpi.c'],['../nnpi_8c.html#ac6c5247850a992a8da4174f43c98b625',1,'nnpi_interpolate_points(int nin, point pin[], double wmin, int nout, point pout[]):&#160;nnpi.c']]],
  ['nnpi_5fnormalize_5fweights',['nnpi_normalize_weights',['../nnai_8c.html#a4702b0f10b5fe80ac92bd1d16aefd2f5',1,'nnpi_normalize_weights(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#a4702b0f10b5fe80ac92bd1d16aefd2f5',1,'nnpi_normalize_weights(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5freset',['nnpi_reset',['../nnai_8c.html#ae313bc0d58c3e179cd1e38a7e77f4e98',1,'nnpi_reset(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#ae313bc0d58c3e179cd1e38a7e77f4e98',1,'nnpi_reset(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fset_5fpoint',['nnpi_set_point',['../nnai_8c.html#a3a151643fcbff5ddbd62943e46d59b55',1,'nnpi_set_point(nnpi *nn, point *p):&#160;nnpi.c'],['../nnpi_8c.html#a3a151643fcbff5ddbd62943e46d59b55',1,'nnpi_set_point(nnpi *nn, point *p):&#160;nnpi.c']]],
  ['nnpi_5fsetwmin',['nnpi_setwmin',['../nn_8h.html#a5f8f33be07c5bf5b34c6fce9c14f3514',1,'nnpi_setwmin(nnpi *nn, double wmin):&#160;nnpi.c'],['../nnpi_8c.html#a5f8f33be07c5bf5b34c6fce9c14f3514',1,'nnpi_setwmin(nnpi *nn, double wmin):&#160;nnpi.c']]],
  ['nnpi_5ftriangle_5fprocess',['nnpi_triangle_process',['../nnpi_8c.html#aa982483e1858d949eca8daae3f3f5828',1,'nnpi.c']]],
  ['nobuffernopixmap',['NoBufferNoPixmap',['../plimage_8c.html#ae8e430d1198bc0c24d3045a83d315d2a',1,'NoBufferNoPixmap():&#160;plimage.c'],['../plplotP_8h.html#a9b62a55b84cec4a17aedb04d620d46e0',1,'NoBufferNoPixmap(void):&#160;plimage.c']]],
  ['noop_5f',['NOOP_',['../aqt_8c.html#abeac3b50d9d45fd9c7436e2a3160a9e6',1,'aqt.c']]],
  ['normalize_5fmjd',['normalize_MJD',['../qsastime_8c.html#a787d737e70b38e667dc1f9cd013752dc',1,'normalize_MJD(MJDtime *MJD):&#160;qsastime.c'],['../qsastimeP_8h.html#ae21d8c71f559b9b98c9c867639f5808e',1,'normalize_MJD(MJDtime *MJD):&#160;qsastime.c']]],
  ['notcrossed',['notcrossed',['../plfill_8c.html#a24898bba1ddfe1f2ef80e596395d64e6',1,'plfill.c']]],
  ['notpointinpolygon',['notpointinpolygon',['../plfill_8c.html#afd685a9865154cab6d110305b13b9898',1,'plfill.c']]]
];

==> plplot-5.15.0.tar.gz: plplot-5.15.0/doc/doxygen/html/search/functions_d.js <==
var searchData=
[
  ['n2q',['n2q',['../csa_8c.html#a1e25648a3bbcc22eefc791dae8584da3',1,'csa.c']]],
  ['nextpage',['NextPage',['../plplotter_8c.html#ada6ffbd50407eb5fa8c54408aa5ff65b',1,'NextPage(Tcl_Interp *, PlPlotter *, int, CONST char **):&#160;plplotter.c'],['../plplotter_8c.html#a4ac458c0f599e34821e980876104366c',1,'NextPage(Tcl_Interp *interp, register PlPlotter *plPlotterPtr, int argc, CONST char **PL_UNUSED(argv)):&#160;plplotter.c']]],
  ['nn_5fquit',['nn_quit',['../nnai_8c.html#aa74fb4b5bc70560fa58e6d2e32124e4b',1,'nn_quit(const char *format,...):&#160;nncommon.c'],['../nncommon_8c.html#aa74fb4b5bc70560fa58e6d2e32124e4b',1,'nn_quit(const char *format,...):&#160;nncommon.c'],['../nnpi_8c.html#aa74fb4b5bc70560fa58e6d2e32124e4b',1,'nn_quit(const char *format,...):&#160;nncommon.c']]],
  ['nnai_5fbuild',['nnai_build',['../nn_8h.html#a100f5dd2bea6f1cdc38cd5aeaded290f',1,'nnai_build(delaunay *d, int n, double *x, double *y):&#160;nnai.c'],['../nnai_8c.html#a100f5dd2bea6f1cdc38cd5aeaded290f',1,'nnai_build(delaunay *d, int n, double *x, double *y):&#160;nnai.c']]],
  ['nnai_5fdestroy',['nnai_destroy',['../nn_8h.html#a8f632f77d6ebbdd5f089b2ac1a8fb19c',1,'nnai_destroy(nnai *nn):&#160;nnai.c'],['../nnai_8c.html#a8f632f77d6ebbdd5f089b2ac1a8fb19c',1,'nnai_destroy(nnai *nn):&#160;nnai.c']]],
  ['nnai_5finterpolate',['nnai_interpolate',['../nn_8h.html#ac3e0c1fbe589c8ab85f9206c28e5eea6',1,'nnai_interpolate(nnai *nn, double *zin, double *zout):&#160;nnai.c'],['../nnai_8c.html#ac3e0c1fbe589c8ab85f9206c28e5eea6',1,'nnai_interpolate(nnai *nn, double *zin, double *zout):&#160;nnai.c']]],
  ['nnai_5fsetwmin',['nnai_setwmin',['../nn_8h.html#aca836e74dc7b0a1d0175263ce86db6f7',1,'nnai_setwmin(nnai *nn, double wmin):&#160;nnai.c'],['../nnai_8c.html#aca836e74dc7b0a1d0175263ce86db6f7',1,'nnai_setwmin(nnai *nn, double wmin):&#160;nnai.c']]],
  ['nndllimpexp_5fdata',['NNDLLIMPEXP_DATA',['../nn_8h.html#ae0d9952ca6772ec1a2c322b79de7e409',1,'nn.h']]],
  ['nnhpi_5fcreate',['nnhpi_create',['../nn_8h.html#a63afdbb12466d8f0fa6a92cc560626cb',1,'nnhpi_create(delaunay *d, int size):&#160;nnpi.c'],['../nnpi_8c.html#a63afdbb12466d8f0fa6a92cc560626cb',1,'nnhpi_create(delaunay *d, int size):&#160;nnpi.c']]],
  ['nnhpi_5fdestroy',['nnhpi_destroy',['../nn_8h.html#af805b7c134095adcfe445d04a1780751',1,'nnhpi_destroy(nnhpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#af805b7c134095adcfe445d04a1780751',1,'nnhpi_destroy(nnhpi *nn):&#160;nnpi.c']]],
  ['nnhpi_5finterpolate',['nnhpi_interpolate',['../nn_8h.html#a6e1fbbdaba1c48008e16b3d65c1ec423',1,'nnhpi_interpolate(nnhpi *nn, point *p):&#160;nnpi.c'],['../nnpi_8c.html#a5b97d1ae6654d20963afbdd700bc9475',1,'nnhpi_interpolate(nnhpi *nnhp, point *p):&#160;nnpi.c']]],
  ['nnhpi_5fmodify_5fdata',['nnhpi_modify_data',['../nn_8h.html#a3decc00fe86197535faf340c071c4187',1,'nnhpi_modify_data(nnhpi *nn, point *p):&#160;nnpi.c'],['../nnpi_8c.html#a5fe3c0f0f14ba9724316b49c055e17c5',1,'nnhpi_modify_data(nnhpi *nnhp, point *p):&#160;nnpi.c']]],
  ['nnhpi_5fsetwmin',['nnhpi_setwmin',['../nn_8h.html#ada49b80c66b0b454cf9c767aac6e9622',1,'nnhpi_setwmin(nnhpi *nn, double wmin):&#160;nnpi.c'],['../nnpi_8c.html#ada49b80c66b0b454cf9c767aac6e9622',1,'nnhpi_setwmin(nnhpi *nn, double wmin):&#160;nnpi.c']]],
  ['nnpi_5fadd_5fweight',['nnpi_add_weight',['../nnpi_8c.html#a156da6be13470e2871b79f0e9e51e357',1,'nnpi.c']]],
  ['nnpi_5fcalculate_5fweights',['nnpi_calculate_weights',['../nnai_8c.html#ae678a0d48730f7e83c8a2c014ed6ee9f',1,'nnpi_calculate_weights(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#ae678a0d48730f7e83c8a2c014ed6ee9f',1,'nnpi_calculate_weights(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fcreate',['nnpi_create',['../nn_8h.html#aedcc30006ab88310a79e0e209631c498',1,'nnpi_create(delaunay *d):&#160;nnpi.c'],['../nnpi_8c.html#aedcc30006ab88310a79e0e209631c498',1,'nnpi_create(delaunay *d):&#160;nnpi.c']]],
  ['nnpi_5fdestroy',['nnpi_destroy',['../nn_8h.html#a33db53e6adc0c3997fd8bb40b643c055',1,'nnpi_destroy(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#a33db53e6adc0c3997fd8bb40b643c055',1,'nnpi_destroy(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fget_5fnvertices',['nnpi_get_nvertices',['../nnai_8c.html#a98f78819ec51952b6d345cd412734c2a',1,'nnpi_get_nvertices(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#a98f78819ec51952b6d345cd412734c2a',1,'nnpi_get_nvertices(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fget_5fvertices',['nnpi_get_vertices',['../nnai_8c.html#a4c6b67ae981d5c38a44a2b2f1f187691',1,'nnpi_get_vertices(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#a2f63ce3a965902fd447069e2020f55dd',1,'nnpi_get_vertices(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fget_5fweights',['nnpi_get_weights',['../nnai_8c.html#acf3056c75581a8a40b63eefac3de04c9',1,'nnpi_get_weights(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#ae9f69c53b06d4ee1a5bc29441af16b4d',1,'nnpi_get_weights(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5finterpolate_5fpoint',['nnpi_interpolate_point',['../nn_8h.html#a5975e4d072aa2275b5a0231770d97251',1,'nnpi_interpolate_point(nnpi *nn, point *p):&#160;nnpi.c'],['../nnpi_8c.html#a5975e4d072aa2275b5a0231770d97251',1,'nnpi_interpolate_point(nnpi *nn, point *p):&#160;nnpi.c']]],
  ['nnpi_5finterpolate_5fpoints',['nnpi_interpolate_points',['../nn_8h.html#ade086ca1784d7687d20ed7e48cd666f5',1,'nnpi_interpolate_points(int nin, point pin[], double wmin, int nout, point pout[]):&#160;nnpi.c'],['../nnpi_8c.html#ac6c5247850a992a8da4174f43c98b625',1,'nnpi_interpolate_points(int nin, point pin[], double wmin, int nout, point pout[]):&#160;nnpi.c']]],
  ['nnpi_5fnormalize_5fweights',['nnpi_normalize_weights',['../nnai_8c.html#a4702b0f10b5fe80ac92bd1d16aefd2f5',1,'nnpi_normalize_weights(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#a4702b0f10b5fe80ac92bd1d16aefd2f5',1,'nnpi_normalize_weights(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5freset',['nnpi_reset',['../nnai_8c.html#ae313bc0d58c3e179cd1e38a7e77f4e98',1,'nnpi_reset(nnpi *nn):&#160;nnpi.c'],['../nnpi_8c.html#ae313bc0d58c3e179cd1e38a7e77f4e98',1,'nnpi_reset(nnpi *nn):&#160;nnpi.c']]],
  ['nnpi_5fset_5fpoint',['nnpi_set_point',['../nnai_8c.html#a3a151643fcbff5ddbd62943e46d59b55',1,'nnpi_set_point(nnpi *nn, point *p):&#160;nnpi.c'],['../nnpi_8c.html#a3a151643fcbff5ddbd62943e46d59b55',1,'nnpi_set_point(nnpi *nn, point *p):&#160;nnpi.c']]],
  ['nnpi_5fsetwmin',['nnpi_setwmin',['../nn_8h.html#a5f8f33be07c5bf5b34c6fce9c14f3514',1,'nnpi_setwmin(nnpi *nn, double wmin):&#160;nnpi.c'],['../nnpi_8c.html#a5f8f33be07c5bf5b34c6fce9c14f3514',1,'nnpi_setwmin(nnpi *nn, double wmin):&#160;nnpi.c']]],
  ['nnpi_5ftriangle_5fprocess',['nnpi_triangle_process',['../nnpi_8c.html#aa982483e1858d949eca8daae3f3f5828',1,'nnpi.c']]],
  ['nobuffernopixmap',['NoBufferNoPixmap',['../plimage_8c.html#ae8e430d1198bc0c24d3045a83d315d2a',1,'NoBufferNoPixmap():&#160;plimage.c'],['../plplotP_8h.html#a9b62a55b84cec4a17aedb04d620d46e0',1,'NoBufferNoPixmap(void):&#160;plimage.c']]],
  ['noop_5f',['NOOP_',['../aqt_8c.html#abeac3b50d9d45fd9c7436e2a3160a9e6',1,'aqt.c']]],
  ['normalize_5fmjd',['normalize_MJD',['../qsastime_8c.html#a787d737e70b38e667dc1f9cd013752dc',1,'normalize_MJD(MJDtime *MJD):&#160;qsastime.c'],['../qsastimeP_8h.html#ae21d8c71f559b9b98c9c867639f5808e',1,'normalize_MJD(MJDtime *MJD):&#160;qsastime.c']]],
  ['notcrossed',['notcrossed',['../plfill_8c.html#a24898bba1ddfe1f2ef80e596395d64e6',1,'plfill.c']]],
  ['notpointinpolygon',['notpointinpolygon',['../plfill_8c.html#afd685a9865154cab6d110305b13b9898',1,'plfill.c']]],
  ['numeric_5fconversion_5ffunction',['numeric_conversion_function',['../classoctave__swig__ref.html#a952436be2d882328c5ac74df42a5b221',1,'octave_swig_ref']]]
];
